@@ -37,6 +37,7 @@ from collections.abc import Awaitable
 from dataclasses import dataclass
 
 from chatto.message import Message
+from chatto.secrets import Secrets
 from chatto.stream import Stream
 
 log = logging.getLogger(__name__)
@@ -63,8 +64,25 @@ class StreamFetchedEvent(Event):
     stream: Stream
 
 
+@dataclass(eq=True, frozen=True)
+class ChatPolledEvent(Event):
+    data: dict[str, t.Any]
+
+
+@dataclass(eq=True, frozen=True)
+class MessageSentEvent(Event):
+    message: Message
+
+
+@dataclass(eq=True, frozen=True)
+class AuthorisedEvent(Event):
+    secrets: Secrets
+    oauth_tokens: dict[str, t.Any]
+
+
 if t.TYPE_CHECKING:
     CallbacksT = dict[t.Type[Event], list[t.Callable[[Event], Awaitable[t.Any]]]]
+    ListenerT = t.Callable[[t.Callable[[t.Any], t.Any]], None]
 
 
 class EventHandler:
@@ -102,3 +120,6 @@ class EventHandler:
                 f"Subscribed to {event_type.__name__} events "
                 f"with callback '{cb.__name__}'"
             )
+
+    def listen(self, event_type: type[Event]) -> ListenerT:
+        return lambda callback: self.subscribe(event_type, callback)
